@@ -7,8 +7,8 @@
 PROJECT_ROOT=$(dirname "$(dirname "$(realpath "$0")")")
 TABLEPATH="$PROJECT_ROOT/table"
 
-TABLE1=$TABLEPATH/unicode.tbl
-TABLE2=$TABLEPATH/unidecode.tbl
+TABLE1=$TABLEPATH/legacy/unicode.tbl
+TABLE2=$TABLEPATH/legacy/unidecode.tbl
 
 START_HEX=0x0080
 
@@ -64,14 +64,15 @@ for CHAR in $CHARS ; do
 	CURRENT_HEX=$(printf "0x%04X" "$CURRENT")
 
 	if [ "$CHAR" = "undef" ] ; then
-		echo "# $CURRENT_HEX		undef"
+		echo "$CURRENT_HEX		\"-\"		# undefined, or control character"
 	else
 		CHECK=$(grep -c 0x"$CHAR" "$TABLE1")
 		if [ "$CHECK" -eq "1" ] ; then
-			grep 0x"$CHAR" "$TABLE1" | sed -e"s/^0x[0-9A-F]\{4,\}/$CURRENT_HEX/"
+			echo -n "$CURRENT_HEX		\"\\u$CHAR\"	# "
+			grep 0x"$CHAR" "$TABLE1" | sed -e"s/^.*# //"
 		else
-			echo -n "# "
-			grep 0x"$CHAR" "$TABLE2" | sed -e"s/^0x[0-9A-F]\{4,\}/$CURRENT_HEX/"
+			echo -n "$CURRENT_HEX		\"\\u$CHAR\"	# "
+			grep 0x"$CHAR" "$TABLE2" | sed -e"s/^.*# //"
 		fi
 	fi
 
