@@ -10,8 +10,8 @@
 #ifndef __CONFIG_FILE_DUMP_H
 #define __CONFIG_FILE_DUMP_H
 
-#include "detox.h"
+#include "detox_struct.h"
 
-extern void dump_config_file(struct detox_parse_results *parse_results, struct detox_options *main_options);
+extern void dump_config_file(config_file_t *config_file, options_t *main_options);
 
-#endif				/* __CONFIG_FILE_DUMP_H */
+#endif /* __CONFIG_FILE_DUMP_H */
